from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('fiber', '0002_callable_upload_to'),
    ]
    operations = [
        migrations.AlterField(
            model_name='page',
            name='level',
            field=models.PositiveIntegerField(editable=False),
        ),
        migrations.AlterField(
            model_name='page',
            name='lft',
            field=models.PositiveIntegerField(editable=False),
        ),
        migrations.AlterField(
            model_name='page',
            name='rght',
            field=models.PositiveIntegerField(editable=False),
        ),
    ]
